<?php
$lang['0_product'] = 'Produkt';
$lang['1_service'] = 'Služba';
$lang['2_discount'] = 'Zľava';
$lang['3_shipping'] = 'Dodanie';
$lang['4_tax'] = 'Daň';
$lang['addedit_billingform_template'] = 'Pridať/upraviť &scaron;abl&oacute;nu pre formul&aacute;r pre fakt&uacute;ry';
$lang['addedit_completion_template'] = 'Pridať/upraviť &scaron;abl&oacute;nu pre dokončenie objedn&aacute;vky';
$lang['addedit_confirmorder_template'] = 'Pridať/upraviť &scaron;abl&oacute;nu pre potvrdenie objedn&aacute;vky';
$lang['addedit_gateway_complete_template'] = 'Pridať/upraviť Gateway Complete Template';
$lang['addedit_invoice_template'] = 'Pridať/upraviť vzorov&uacute; fakt&uacute;ru';
$lang['addedit_paymentform_template'] = 'Pridať/upraviť &scaron;abl&oacute;nu pre formul&aacute;r pre platbu';
$lang['address1'] = 'Adresa';
$lang['address2'] = 'Adresa 2';
$lang['address_handling'] = 'Adresa';
$lang['add_msg_template'] = 'Pridať &scaron;abl&oacute;nu pre nov&uacute; spr&aacute;vu';
$lang['admin_email_addresses'] = 'E-mailov&eacute; adresy administr&aacute;torov oddelen&eacute; čiarkov, na ktor&yacute; je odosielan&yacute; e-mail po odoslan&iacute; objedn&aacute;vky';
$lang['admin_email_template'] = '&Scaron;abl&oacute;na pre e-mail pre administr&aacute;tora';
$lang['amount'] = 'Hodnota';
$lang['amt_due'] = 'Amt. Due';
$lang['any'] = 'Žiadny';
$lang['ask_delete'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť položku';
$lang['ask_delete_order'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť t&uacute;to objedn&aacute;vku? Lep&scaron;ia voľba je, keď nastav&iacute;te objedn&aacute;vke status zru&scaron;en&aacute;.   ';
$lang['ask_delete_payment'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť v&scaron;etky z&aacute;znamy s&uacute;visiae s touto platbou?';
$lang['ask_edit_billing'] = 'Ste si ist&yacute;, že chcete modifikovať fakturačn&eacute; &uacute;daje tejto objedn&aacute;vky uveden&eacute; vy&scaron;&scaron;ie?';
$lang['ask_manual_payment'] = 'Ste si ist&yacute;, že chcete prejsť k platbe kartou? ';
$lang['ask_saveprefs'] = 'Are you sure you want to adjust the preferences of this module?\nUse caution, incorrect adjustments may break a working website.';
$lang['ask_setorderstatus'] = 'Bola zisten&aacute; zmena stavu objedn&aacute;vky, chcete stav zmeniť na: ';
$lang['back'] = 'Sp&auml;ť';
$lang['back_to_orders'] = 'Sp&auml;ť k objedn&aacute;vkam';
$lang['backorder'] = 'Sp&auml;ť k objednan&yacute;m';
$lang['balancedue'] = 'Nedoplatok (čiastočne zaplaten&eacute;)';
$lang['bill_to'] = 'Fakturačn&aacute; adresa';
$lang['billing_address'] = 'Fakturačn&aacute; adresa';
$lang['billing_form_templates'] = '&Scaron;abl&oacute;na pre fakturačn&eacute; &uacute;daje';
$lang['billing_info'] = 'Fakturačn&eacute; inform&aacute;cie';
$lang['body'] = 'Obsah spr&aacute;vy';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['cancelled'] = 'Zru&scaron;en&eacute;';
$lang['captcha_title'] = 'Captcha text';
$lang['cart_module'] = 'Modul pre ko&scaron;&iacute;k';
$lang['cart_settings'] = 'Nastavenia ko&scaron;&iacute;ka';
$lang['cash'] = 'Hotovosť';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Discover';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'Mesto';
$lang['completed'] = 'Dokončen&aacute;';
$lang['completion_templates'] = '&Scaron;abl&oacute;na pre dokončenie';
$lang['confirmed'] = 'Potvrden&eacute;';
$lang['confirm_order'] = 'Potvrdte va&scaron;u objedn&aacute;vku';
$lang['confirmation_form_templates'] = '&Scaron;alb&oacute;na pre formul&aacute;r potvrdenia objedn&aacute;vky';
$lang['confirmation_num'] = 'Potvdzovacie č&iacute;slo';
$lang['country'] = 'Krajina';
$lang['coupon_code'] = 'K&oacute;d kup&oacute;nu';
$lang['created'] = 'Vytvoren&eacute;';
$lang['create_invoice'] = 'Vytvoriť fakt&uacute;ru pre t&uacute;to objedn&aacute;vku';
$lang['create_invoice_for'] = 'Vytvoriť fakt&uacute;ru pre objedn&aacute;vku %s';
$lang['creditcard'] = 'Kreditka';
$lang['creditcard_expiry'] = 'Expir&aacute;cia kreditnej karty';
$lang['creditcard_number'] = 'Č&iacute;slo kreditnej karty';
$lang['creditcard_type'] = 'Typ kreditnej karty';
$lang['creditcard_verifycode'] = 'Kontroln&yacute; k&oacute;d';
$lang['customer_name'] = 'Meno z&aacute;kazn&iacute;ka';
$lang['date'] = 'D&aacute;tum';
$lang['default_templates'] = 'Prednastaven&eacute; &scaron;abl&oacute;ny';
$lang['delete'] = 'Odstr&aacute;niť';
$lang['description'] = 'Popis';
$lang['destinations'] = 'Destin&aacute;cia';
$lang['details'] = 'Detaily';
$lang['dflt_billingform_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre formul&aacute;r faktur&aacute;cie';
$lang['dflt_confirmorder_template'] = 'Prednastavenňa &scaron;abl&oacute;na pre formul&aacute;r potvrdenia objedn&aacute;vky';
$lang['dflt_completion_template'] = 'Prednastaven&aacute; &Scaron;abl&oacute;na pre dokončenie objen&aacute;vky';
$lang['dflt_gateway_complete_template'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre Dokončenie platby cez platobn&uacute; br&aacute;nu ';
$lang['dflt_invoice_message'] = 'Ďakujeme z&aacute; n&aacute;kup u n&aacute;s.';
$lang['dflt_invoice_template'] = 'Prednastaven&aacute; vzorov&aacute; fakt&uacute;ra';
$lang['dflt_paymentform_template'] = 'Prednastaven&yacute; formular pre platbu';
$lang['discount'] = 'Zľava';
$lang['edit'] = 'Upraviť';
$lang['edit_billing_info'] = 'Aktualizovať fakturačn&eacute; &uacute;daje';
$lang['email'] = 'E-mail';
$lang['email_address'] = 'E-mailov&eacute; adresy';
$lang['email_invoice'] = 'Odoslať t&uacute;to fakt&uacute;ru na e-mail a adminovi';
$lang['email_sent_to'] = 'Odoslanie e-mailu na adresy';
$lang['email_subject'] = 'Predmet e-mailu';
$lang['error_badcaptcha'] = 'Captcha bola nespr&aacute;vne vyplnen&aacute;';
$lang['error_creditcard_expired'] = 'Platnosť karty už vypr&scaron;ala';
$lang['error_encryption_problem'] = 'Problem pri &scaron;ifrov&aacute;ni a de&scaron;ifrov&aacute;ni d&aacute;t';
$lang['error_gateway_invalid_data'] = 'Nie je možn&eacute; potvrdiť d&aacute;ta z platobnej br&aacute;ny';
$lang['error_insufficientparams'] = 'Ch&yacute;baj&uacute; požadovan&eacute; parametre ';
$lang['error_invalid_address'] = 'Zadan&aacute; adresa neexistuje (pros&iacute;m uistite sa, že s&uacute; v&scaron;etky polia vyplnen&eacute;)
';
$lang['error_invalidfield'] = 'Nasleduj&uacute;ce polia s&uacute; chybn&eacute;: %s';
$lang['error_invalidgateway'] = 'Vybran&aacute; platobn&aacute; br&aacute;na nie je platn&aacute; pre tento &uacute;čel';
$lang['error_missingshippinginfo'] = 'Inform&aacute;cie su nedostatočn&eacute; pre dodanie';
$lang['error_namexists'] = 'Položka s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_nocartmodule'] = 'Nen&aacute;jden&yacute; modul ko&scaron;&iacute;ka';
$lang['error_noemailaddress'] = 'Nie je e-mail nie je pre tohto už&iacute;vateľa';
$lang['error_nofeumodule'] = 'Nen&aacute;jden&yacute; modul FrontEndUsers ';
$lang['error_nopaymentgateway'] = 'Nie je žiadny platobn&yacute; modul';
$lang['error_noproductsmodule'] = 'Nem&ocirc;žem n&aacute;jsť produktov&yacute; modul';
$lang['error_norequiredgroup'] = 'Pros&iacute;m. vyberte požadovan&uacute; skupinu pre pr&iacute;stup v z&aacute;ložke s nastaveniami ';
$lang['error_notloggedin'] = 'Už&iacute;vateľ nepr&iacute;hlasen&yacute;';
$lang['error_orderinvalid'] = 'Nastal probl&eacute;m s touto objedn&aacute;vkou (inform&aacute;cie sa nezhoduj&uacute;)';
$lang['error_ordernotfound'] = 'Požadovan&aacute; objedn&aacute;vka nebola n&aacute;jden&aacute;';
$lang['error_orderprocessing'] = 'Chyba pri spracovan&iacute; objedn&aacute;vky';
$lang['error_paymentnotfound'] = 'Nebola n&aacute;jden&aacute; žiadna platba';
$lang['error_requiressl'] = 'Platobn&aacute; br&aacute;na vyžaduje bepečn&eacute; pripojenie, ktor&eacute; nie je dostupn&eacute;';
$lang['error_retrieve_data'] = 'Nastali probl&eacute;mi pri z&iacute;skan&iacute; relevantn&yacute;ch &uacute;dajov z datab&aacute;zy';
$lang['error_save'] = 'Chyba pri uložen&iacute; d&aacute;t: %s';
$lang['error_security_key'] = '&Scaron;ifrovacie kľuče pre t&uacute;to transakciu nen&aacute;jden&eacute;';
$lang['error_paymentgateway_incompatible'] = 'Vybran&aacute; platobn&aacute; br&aacute;na je nekompatibiln&aacute; s modulom. Pros&iacute;m, kontaktujte administr&aacute;tora';
$lang['error_permissiondenied'] = 'Pr&iacute;stup zamietnut&yacute;';
$lang['error_unknownstatus'] = 'Zaznamenan&yacute; nezn&aacute;mi status z platobn&eacute;ho modulu';
$lang['error_usernotingroup'] = 'Aktu&aacute;lne prihl&aacute;sen&yacute; už&iacute;vateľ nie je členom požadovanej skupiny';
$lang['fax'] = 'Fax';
$lang['filter'] = 'Filter';
$lang['first_name'] = 'Meno';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Spr&aacute;vca objedn&aacute;vok';
$lang['from'] = 'Z';
$lang['gateway_module'] = 'Modul platobnej br&aacute;ny';
$lang['gateway_complete_templates'] = '&Scaron;abl&oacute;ny dokončenia platby';
$lang['gateway_failure_message'] = 'Va&scaron;a transakcia nebola dokončen&aacute;. Pros&iacute;m potvrďte va&scaron;e platobn&eacute; &uacute;daje e&scaron;te raz. Z bezpečnostn&yacute;ch d&ocirc;vodov bol vypr&aacute;zden&yacute; ko&scaron;&iacute;k.  ';
$lang['general_settings'] = 'Hlavn&eacute; nastavenia';
$lang['get_address_from_feu'] = 'Použitie profilu pre z&aacute;kazn&iacute;ka';
$lang['help_param_invoice_prefix'] = 'Tento parameter ud&aacute;va prefix pre generovanie č&iacute;sla fakt&uacute;ry (max. 4 znaky). ';
$lang['help_param_nocaptcha'] = 'Ak je tento parameter akt&iacute;vny, captcha bude neakt&iacute;vna';
$lang['help_param_template'] = '&Scaron;pecifikuj neprednastaven&uacute; &scaron;abl&oacute;nu pre t&uacute;t akciu';
$lang['hold'] = 'Podržať';
$lang['html'] = 'HTML';
$lang['html_email'] = 'Poslať e-mail v html form&aacute;te';
$lang['id'] = 'ID';
$lang['incomplete'] = 'Ne&uacute;pln&aacute; (čiastočne odoslan&aacute;)';
$lang['info_admin_invoice_template'] = 'Vybrať &scaron;abl&oacute;nu pre tlač fakt&uacute;ry';
$lang['info_adminemail_template'] = 'T&aacute;to &scaron;abl&oacute;na obsahuje obsah e-malu, ktor&yacute; je posielan&yacute; administr&aacute;torovi pri novej objedn&aacute;vke';
$lang['info_allow_creditcard_entry'] = '<strong>Note:</strong>T&aacute;to inform&aacute;cie je uložen&aacute; do DB.<br/>Though encryption is used to store private data,<br/>it is recommended that this option never be used.<br/>Instead, please use a compatible payment gateway module.';
$lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
$lang['info_ccprocessing_module'] = 'Tento modul  využ&iacute;va manu&aacute;lne spracovanie kreditn&yacute;ch kariet';
$lang['info_coupon_code'] = 'Vložte k&oacute;d kup&oacute;nu pre možn&uacute; zľavu';
$lang['info_default_templates'] = 'T&aacute;to &scaron;abl&oacute;na obsahuje prednastaven&yacute; obsah po kliknut&iacute; pri vytvoren&iacute; novej &scaron;abl&oacute;ny v časti &#039;&Scaron;abl&oacute;ny pre potvrdenie objedn&aacute;vky&#039;. Edit&aacute;cia nem&aacute; žiadny vplyv na  už vytvoren&eacute; &scaron;abl&oacute;ny.';
$lang['info_encryption_key'] = 'Tento kľuč sa n&aacute;hodne generuje pri in&scaron;tal&aacute;cia modulu. Budte opatrn&yacute; pri jeho edit&aacute;cii, m&ocirc;že mať vplyv na už rie&scaron;ene objedn&aacute;vky.';
$lang['info_forcessl'] = '<strong>Note: Recommended</strong>.  If you are allowing customers to enter credit card information, you should enable this option and ensure that you have properly configured your site for SSL access to ensure that the transmission of credit card information is done over an encrypted connection.';
$lang['info_gateway_description'] = 'This information is sent to the payment gateway for each transaction, and may be used for information such as the name that shows up to clients on their credit card statements';
$lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as the success and failure page for payment gateways';
$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
$lang['info_order_notes'] = 'Supply some special notes for this order';
$lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This option stores the user entered credit card information in the database for later use in the admin panel.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
$lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
$lang['info_use_integer'] = 'Použi iba celoč&iacute;seln&eacute; hodnoty';
$lang['interval_oneday'] = 'Denne';
$lang['interval_onemonth'] = 'Mesačne';
$lang['interval_onequarter'] = '&Scaron;tvrťročne';
$lang['interval_oneweek'] = 'T&yacute;ždeňne';
$lang['interval_oneyear'] = 'Ročne';
$lang['interval_twoweeks'] = 'Raz za dva t&yacute;ždne';
$lang['invoice'] = 'Fakt&uacute;ra';
$lang['invoiced'] = 'Fakturovan&eacute;';
$lang['invoice_settings'] = 'Nastavenia fakt&uacute;ry';
$lang['invoice_templates'] = '&Scaron;abl&oacute;ny fakt&uacute;ry';
$lang['items'] = 'Položky';
$lang['last_name'] = 'Priezvisko';
$lang['last_modified'] = 'Posledn&aacute; &uacute;prava';
$lang['lastpage'] = '>>';
$lang['lbl_back'] = 'Sp&auml;ť';
$lang['lbl_templates'] = '&Scaron;abl&oacute;ny';
$lang['message'] = 'Spr&aacute;va';
$lang['message_templates'] = '&Scaron;abl&oacute;ny spr&aacute;v';
$lang['method'] = 'Sp&ocirc;sob';
$lang['moddescription'] = 'Jednoduch&yacute; moduly pre spr&aacute;vu objedn&aacute;vok';
$lang['modified'] = 'Upraven&eacute;';
$lang['msg_order_cancelled'] = 'Objedn&aacute;vka %s zru&scaron;en&aacute; alebo odmietnut&aacute;';
$lang['msg_order_error'] = 'Chyba pri objedn&aacute;vke %s';
$lang['msg_order_payment'] = 'Prijat&aacute; platba pre objedn&aacute;vku %s.';
$lang['msg_order_pending'] = 'Stav objedn&aacute;vky %s sa zmen&iacute; na &quot;čak&aacute;  sa&quot;  ';
$lang['msg_order_setbackwards'] = 'Nastala zmena stavu objedn&aacute;vky %s sp&auml;ť zo stavu zaplaten&aacute; na čak&aacute; sa';
$lang['msg_async_transaction'] = 'Spracovanie asynchronnej transakcie %s pre objedn&aacute;vku %s';
$lang['msg_payment_removed'] = 'Platba odstr&aacute;nen&aacute; z objedn&aacute;vky';
$lang['name'] = 'N&aacute;zov';
$lang['net'] = 'Net';
$lang['net_price'] = 'Čist&aacute; cena';
$lang['new_order_submitted'] = 'Nov&aacute; objendn&aacute;vka bola odoslan&aacute;';
$lang['next'] = 'Ďal&scaron;ie';
$lang['nextpage'] = '>';
$lang['no'] = 'Nie';
$lang['no_items_in_cart'] = 'Nie s&uacute; žiadne položky v ko&scaron;&iacute;ku.  Pros&iacute;m naplnte najpr ko&scaron;&iacute;k pred začat&iacute;m objedn&aacute;vkov&eacute;ho procesu.';
$lang['none'] = 'Žiadne';
$lang['notcancelledshipped'] = 'Ak&aacute;koľvek, ale zru&scaron;en&aacute; alebo odoslan&aacute;';
$lang['notes'] = 'Pozn&aacute;mky';
$lang['notshipped'] = 'Nie je dodan&yacute;';
$lang['num'] = 'Nie';
$lang['online'] = 'on-line';
$lang['order'] = 'Objedn&aacute;vka';
$lang['orders'] = 'Objedn&aacute;vky';
$lang['order_confirm_form_templates'] = '&Scaron;abl&oacute;ny pre formul&aacute;r pre potvrdenie objedn&aacute;vky';
$lang['order_details'] = 'Detaily objedn&aacute;vky';
$lang['order_notes'] = 'Pozn&aacute;mky k objedn&aacute;vky';
$lang['order_number'] = 'Č&iacute;slo objedn&aacute;vky';
$lang['order_processing'] = 'Priebeh objedn&aacute;vky';
$lang['order_statistics'] = '&Scaron;tatistika objedn&aacute;vky';
$lang['order_summary'] = 'Prehľad objedn&aacute;vky';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Zľava';
$lang['paid'] = 'Zaplatne&eacute;';
$lang['payment_amount'] = 'V&yacute;&scaron;ka platby';
$lang['payment_approved'] = 'Schv&aacute;len&aacute;';
$lang['payment_cancelled'] = 'Zru&scaron;en&aacute;';
$lang['payment_date'] = 'D&aacute;tumy platby';
$lang['payment_declined'] = 'Odmietnut&aacute;';
$lang['payment_error'] = 'Chyba';
$lang['payment_form_templates'] = '&Scaron;abl&oacute;na platobnej br&aacute;ny';
$lang['payment_gateway_settings'] = 'Nastavenia platobnej br&aacute;ny';
$lang['payment_info'] = 'Inform&aacute;cie o platbe';
$lang['payment_method'] = 'Sp&ocirc;sob platby';
$lang['payment_notprocessed'] = 'Neprebehla';
$lang['payment_options'] = 'Nastavenia platby';
$lang['payment_other'] = 'Ostatn&eacute;';
$lang['payment_pending'] = 'Čak&aacute; sa';
$lang['payment_status'] = 'Stav platby';
$lang['pending'] = 'Čak&aacute; sa';
$lang['phone'] = 'Telef&oacute;n';
$lang['popup_new_window'] = 'Popup fakt&uacute;ry v novom okne';
$lang['postinstall'] = 'Modul pre spr&aacute;vu objedn&aacute;vok bol nain&scaron;talovn&yacute;';
$lang['postuninstall'] = 'Modul pre spr&aacute;vu objedn&aacute;vok a jeho data boli odstr&aacute;nen&eacute;';
$lang['post_order_msg'] = 'Spr&aacute;va po dokončen&iacute; objedn&aacute;vky';
$lang['postal'] = 'PSČ';
$lang['preferences'] = 'Nastavenia';
$lang['prevpage'] = '<';
$lang['price'] = 'Cena';
$lang['print_invoice'] = 'Vytlačiť fakt&uacute;ru';
$lang['procede_manual_checkout'] = 'Pokračovať do pokladne';
$lang['process_manual_payment'] = 'Process Manual Payment';
$lang['process_new_transaction'] = 'Transakcia pomocou platobnej br&aacute;ny';
$lang['process_order'] = 'Objednať';
$lang['product_id'] = 'Id produktu';
$lang['promotions_module'] = 'Darčekov&yacute; modul';
$lang['promotions_settings'] = 'Nastavenia darčekov';
$lang['prompt_address_property_map'] = 'Adresa do vlastnost&iacute; modulu FEU ';
$lang['prompt_address_retrieval'] = 'Address Retrieval Method';
$lang['prompt_admin_invoice_template'] = '&Scaron;abl&oacute;na  pre vytlačenie fakt&uacute;ry';
$lang['prompt_allow_creditcard_entry'] = 'Povoliť už&iacute;vateľovi vložiť inform&aacute;cie o karte';
$lang['prompt_billingpage'] = 'Page to assume that the billing form will be displayed on.  This is usually the page with your <code>{Orders}</code> tag.';
$lang['prompt_ccprocessing_module'] = 'Platobn&aacute; br&aacute;na';
$lang['prompt_confirmpage'] = 'Str&aacute;nka pre potvrdzovac&iacute; formul&aacute;r';
$lang['prompt_date_search_type'] = 'Filtrovať z&aacute;znami, ktor&eacute; boli';
$lang['prompt_email'] = 'E-mal';
$lang['prompt_encryption_key'] = '&Scaron;ifrovac&iacute; kľ&uacute;č';
$lang['prompt_forcessl'] = 'Presmerovanie na str&aacute;nku HTTPS po vložen&iacute; inform&aacute;cii o platbe';
$lang['prompt_gateway_description'] = 'Popis odoslan&yacute; do platobnej br&aacute;ny';
$lang['prompt_invoice_message'] = 'Text, ktor&yacute; sa zobraz&iacute; na začiatku fakt&uacute;ry';
$lang['prompt_invoicepage'] = 'Str&aacute;nka pre zobrazenie fakt&uacute;ry';
$lang['prompt_of'] = 'z';
$lang['prompt_ordernum_prefix'] = 'Prefix č&iacute;sla objedn&aacute;vky';
$lang['prompt_page'] = 'Strana';
$lang['prompt_pagelimit'] = 'Počet objedn&aacute;vok na str&aacute;nku';
$lang['prompt_paymentpage'] = 'Str&aacute;nka pre platobn&yacute; formul&aacute;r';
$lang['prompt_permit_deletion'] = 'Povolenie odstr&aacute;nenie objedn&aacute;vok z administr&aacute;cie';
$lang['prompt_process_cc_now'] = 'Platba kreditkou';
$lang['prompt_skip_invoice_page'] = 'Preskočiť str&aacute;nku s fakt&uacute;rov';
$lang['prompt_store_creditcard_data'] = 'Uchov&aacute;vať inform&aacute;cie o kredtin&yacute;ch kart&aacute;ch';
$lang['prompt_template'] = '&Scaron;abl&oacute;na spr&aacute;vy';
$lang['prompt_username'] = 'Už&iacute;vateľsk&eacute; meno';
$lang['proposed'] = 'Nedokončen&eacute;';
$lang['quantity'] = 'Počet kusov';
$lang['really_uninstall'] = 'Ste si ist&yacute;? Vsětky d&aacute;ta spojen&eacute; s t&yacute;mto modulom bud&uacute; odstr&aacute;nen&eacute;.';
$lang['records_matching_query'] = 'Počet z&aacute;znamov v&aacute;&scaron;ho v&yacute;beru';
$lang['regex'] = 'Regul&eacute;rny v&yacute;raz';
$lang['remember_last_address_used'] = 'Použiť adresu z poslednej objedn&aacute;vky';
$lang['return'] = 'N&aacute;vrat';
$lang['require_group_membership'] = 'Vyžadovať, aby mohli vykonať objedn&aacute;vku použ&iacute;vatelia z tejto &Scaron;abl&oacute;na e-mailu pre použ&iacute;vateľa skupiny';
$lang['security_settings'] = 'Nastavenina benzpečnosti';
$lang['select_action'] = 'Vybrať akciu';
$lang['select_one'] = 'Vybrať jeden';
$lang['select_invoice_template'] = 'Vybrať &scaron;alb&oacute;nu pre fakt&uacute;ry';
$lang['send'] = 'Odoslať';
$lang['send_message'] = 'Odoslať tomuto z&aacute;kazn&iacute;kovi spr&aacute;vu';
$lang['sent'] = 'Poslať';
$lang['ship_to'] = 'Dodacia adresa';
$lang['shipped'] = 'Odoslan&aacute;';
$lang['shipping'] = 'Dodanie';
$lang['shipping_address'] = 'Adresa pre dodanie';
$lang['shipping_info'] = 'Inform&aacute;cie o dodan&iacute;';
$lang['shipping_info_if_different'] = 'Inform&aacute;cie o dodan&iacute; <em>(ak su odli&scaron;n&eacute; od fakturačn&yacute;ch)</em>';
$lang['shipping_message'] = 'Spr&aacute;vy vzťahuj&uacute;ce sa k tomuto cieľu';
$lang['shipping_module'] = 'Modul pre dodanie';
$lang['shipping_settings'] = 'Nastavenia pre dodanie';
$lang['shipping_total'] = 'Doprava celkom';
$lang['special_instructions'] = '&Scaron;peci&aacute;lne in&scaron;trukcie';
$lang['state/province'] = '&Scaron;t&aacute;t/provincia';
$lang['status'] = 'Stav';
$lang['subject'] = 'Predmet';
$lang['submit'] = 'Odoslať';
$lang['submitted'] = 'Odoslan&eacute;';
$lang['submit_payment_info'] = 'Odolsať inform&aacute;cie o platbe';
$lang['subtotal'] = 'Medzis&uacute;čet';
$lang['tax'] = 'Daň';
$lang['tax_module'] = 'Modul pre daň';
$lang['tax_settings'] = 'Nastavenia pre daň';
$lang['template'] = '&Scaron;abl&oacute;na';
$lang['template_name'] = 'N&aacute;zov &scaron;abl&oacute;ny';
$lang['thank_you_for_order'] = 'Ďakujeme za objedn&aacute;vku.';
$lang['title_adminemail_template'] = '&Scaron;abl&oacute;na e-mailu pre administr&aacute;tora';
$lang['title_first_page'] = 'Prejsť na prv&uacute; stranu';
$lang['title_last_page'] = 'Prejsť na posledn&uacute; stranu';
$lang['title_manage_order'] = 'Spr&aacute;va objedn&aacute;vky';
$lang['title_manual_process'] = 'Manu&aacute;lne spracovanie transakc&iacute;i';
$lang['title_next_page'] = 'Prejsť na nasleduj&uacute;cu stranu';
$lang['title_prev_page'] = 'Prejsť na predch&aacute;dzaj&uacute;cu stranu';
$lang['title_useremail_template'] = '&Scaron;abl&oacute;na e-mailu pre použ&iacute;vateľa';
$lang['to'] = 'Komu';
$lang['total'] = 'Spolu';
$lang['tracking_num'] = 'Č&iacute;slo pre tracking';
$lang['transaction_id'] = 'ID transakcie';
$lang['transaction_successful'] = 'Platba prebehla v poriadku';
$lang['type'] = 'Typ';
$lang['update_status'] = 'Uprav stav';
$lang['unit_price'] = 'Cena za kus';
$lang['unit_weight'] = 'Hmotnosť / kus';
$lang['unknown'] = 'Nezn&aacute;me';
$lang['unlimited'] = 'Neobmedzen&eacute;';
$lang['username'] = 'Už&iacute;vateľsk&eacute; meno';
$lang['user_email_template'] = '&Scaron;abl&oacute;na e-mailu pre použ&iacute;vateľa';
$lang['view'] = 'Zobraziť';
$lang['view_message'] = 'Zobrazenie spr&aacute;vy';
$lang['view_messages'] = 'Zobrazenie spr&aacute;v s&uacute;visiacich s touto objedn&aacute;vkou';
$lang['warning_https'] = '<strong>Upozornenie!</strong> Nepouž&iacute;vate bezpečnostn&eacute; pripojenie (https).  Nedoporučujeme pokračovať v akcii.';
$lang['warning_manual_process'] = '<strong>Upozornenie!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
$lang['warning_order_paid_in_full'] = '<strong>Upozornenie!</strong> T&aacute;to objedn&aacute;vka už bola zaplaten&aacute; ';
$lang['warning_orderstatus_paid'] = '<strong>Upozornenie!</strong> T&aacute;to objedn&aacute;vka už bola zaplaten&aacute;.  ';
$lang['warning_orderstatus_cancelled'] = '<strong>Upozornenie!</strong> T&aacute;to objedn&aacute;vka už bola zru&scaron;en&aacute;.  ';
$lang['weight'] = 'V&aacute;ha';
$lang['within'] = 'V r&aacute;mci';
$lang['yes'] = '&Aacute;no';
$lang['utma'] = '156861353.2102989501.1260383028.1263073560.1263139294.36';
$lang['utmz'] = '156861353.1263073560.35.33.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['qca'] = 'P0-1473547689-1260383028162';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
